# CHANGELOG

<!-- version list -->

## v1.2.0 (2025-12-19)

### Bug Fixes

- Inject naas_abi_core.modules.templatablesparqlquery by default
  ([`b6dc785`](https://github.com/jupyter-naas/abi/commit/b6dc78519e71afb46dd2ffc401539fab19fb865f))

- Review
  ([`6301a5f`](https://github.com/jupyter-naas/abi/commit/6301a5fcda63875b2748a625727903f236772966))

- Review
  ([`1ad319b`](https://github.com/jupyter-naas/abi/commit/1ad319ba2e47463ab84cabf7edbd2b721b053e3b))

### Chores

- Remove comments
  ([`05868ff`](https://github.com/jupyter-naas/abi/commit/05868ff0c60ccb3e7da46cdd8903d207622d5e8c))

- Remove duplicate logger
  ([`8438450`](https://github.com/jupyter-naas/abi/commit/84384505a88b9645e56628b39bfda8da054792cc))

### Features

- Workin on naas-abi-cli
  ([`16cd62d`](https://github.com/jupyter-naas/abi/commit/16cd62d77879d94c83fae9218bd451c1909554e4))


## v1.1.2 (2025-12-05)

### Bug Fixes

- Make it possible to define env secrets from config.yaml
  ([`d9903cf`](https://github.com/jupyter-naas/abi/commit/d9903cfecac03df40a6f3076c7ff44229c0c12cd))


## v1.1.1 (2025-12-05)


## v1.1.0 (2025-12-05)

### Features

- Make it possible to add env var using cli deploy
  ([`eb32c8d`](https://github.com/jupyter-naas/abi/commit/eb32c8d9613ecbddb3a891f25db0a5bc3498b258))


## v1.0.8 (2025-12-05)


## v1.0.7 (2025-12-03)

### Bug Fixes

- Working on embedding assets in the release
  ([`9737428`](https://github.com/jupyter-naas/abi/commit/97374285cb3c79ed03399859c58b8cac6373627d))

- **marketplace**: Convert applications.pubmed to a real module
  ([`b9ac395`](https://github.com/jupyter-naas/abi/commit/b9ac395c0e90980fb19379d40ae5017efcf06d1d))


## v1.0.6 (2025-12-02)

### Bug Fixes

- Working on abi cli
  ([`e1c11a1`](https://github.com/jupyter-naas/abi/commit/e1c11a15a80403fdb1992faa4dcb035fbaf9b5c0))


## v1.0.5 (2025-12-02)

### Bug Fixes

- Working on dependencies
  ([`cfb492f`](https://github.com/jupyter-naas/abi/commit/cfb492f5f1604d405ff0221d505e90101614d59e))


## v1.0.4 (2025-12-02)

### Bug Fixes

- Update release commit parser option
  ([`6eabfd8`](https://github.com/jupyter-naas/abi/commit/6eabfd8f61681240a1974affd377b983bd7885a9))
## v1.0.4-dev.2 (2025-12-02)


## v1.0.4-dev.1 (2025-12-02)

### Bug Fixes

- **naas_abi_core**: Working on dependencies
  ([`54ad989`](https://github.com/jupyter-naas/abi/commit/54ad9896794cf831e503aef22170a0b0485e9e31))


## v1.0.3-dev.1 (2025-12-01)
## v1.0.3 (2025-12-01)

### Bug Fixes

- Working on fixing mypy check for core and naas-abi-marketplace linkedin
  ([`fc11437`](https://github.com/jupyter-naas/abi/commit/fc11437fa5b655805327783016318416d17a0f1b))


## v1.0.2 (2025-12-01)

### Bug Fixes

- Working on fixing mcp-server
  ([`69ba291`](https://github.com/jupyter-naas/abi/commit/69ba291474a171da1652a8769493d35f3d2d3843))


## v1.0.1 (2025-12-01)

### Bug Fixes

- Working on api tests in CI/CD
  ([`5012a3b`](https://github.com/jupyter-naas/abi/commit/5012a3b4408f138d6e5c90a36c6f4d250f56af8a))


## v1.0.0 (2025-12-01)
## v1.0.0-dev.10 (2025-12-01)

### Bug Fixes

- Adding authors and removing uneeded configuration
  ([`c105454`](https://github.com/jupyter-naas/abi/commit/c105454bcb1ed1da88bda6ca23a05e9e3e9c1ed1))

- Configure release on main
  ([`fb32b93`](https://github.com/jupyter-naas/abi/commit/fb32b93ef0e3ce1b8bb291fda902a7a03c0f0646))


## v1.0.0-dev.9 (2025-11-30)

### Bug Fixes

- Working on api deployment
  ([`8a803ba`](https://github.com/jupyter-naas/abi/commit/8a803bad5db9ed9d020d18245b3b6fbafda6bb2c))


## v1.0.0-dev.8 (2025-11-30)


## v1.0.0-dev.7 (2025-11-30)


## v1.0.0-dev.6 (2025-11-30)


## v1.0.0-dev.5 (2025-11-30)

### Bug Fixes

- Working on ci/cd
  ([`d65250c`](https://github.com/jupyter-naas/abi/commit/d65250c10e433595a6ecd124c33aee9ca7e69535))


## v1.0.0-dev.4 (2025-11-30)

### Bug Fixes

- Working on ci
  ([`ba918da`](https://github.com/jupyter-naas/abi/commit/ba918da13147636ec732f2aba3e2978046b93970))


## v1.0.0-dev.3 (2025-11-30)

### Bug Fixes

- Uv install
  ([`c268208`](https://github.com/jupyter-naas/abi/commit/c268208bdcc69223fbb68114978211de7c161956))


## v1.0.0-dev.2 (2025-11-30)

### Bug Fixes

- Remove scoped prefix for semantic releases
  ([`c208c3f`](https://github.com/jupyter-naas/abi/commit/c208c3f12ad1cd2eb2264a166f0e683184efb2ca))


## v1.0.0-dev.1 (2025-11-30)

- Initial Release
